{% raw %}
{% load mote_tags %}
{% render_element element.aspect.basics.languages.language-list-dropdown %}
  <div class="header">
    {% render_element element.aspect.basics.logo.logo-left %}
    {% render_element element.aspect.basics.menu.menu-icon %}
  </div>
{% endraw %}
