{% load wagtailcore_tags comments molo_commenting_tags i18n %}
{% get_comment_count for self as comment_count %}
{% if comment_count > 0 %}
  <a href="{% pageurl self %}#comments-list" class="call-to-action__nav-item-text call-to-action__nav-item-text--article-comments">
    {% trans "Your thoughts" %}
    ({{comment_count}})
  </a>
{% endif %}
