# -*- coding: utf-8 -*-
# Generated by Django 1.9.9 on 2016-09-06 12:35
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('profiles', '0007_add_password_recovery_retries'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userprofilessettings',
            name='num_security_questions',
            field=models.PositiveSmallIntegerField(default=1, verbose_name='Number of security questions asked for password recovery'),
        ),
    ]
