# -*- coding: utf-8 -*-
# Generated by Django 1.11.15 on 2018-09-05 11:59
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0004_add_core_translation_fields'),
        ('profiles', '0002_userprofile_auth_service_uuid'),
    ]

    operations = [
        migrations.AddField(
            model_name='securityquestion',
            name='language',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='core.SiteLanguage'),
        ),
        migrations.AddField(
            model_name='securityquestion',
            name='translated_pages',
            field=models.ManyToManyField(blank=True, related_name='_securityquestion_translated_pages_+', to='profiles.SecurityQuestion'),
        ),
    ]
