.promoted-article {
    &__section-title {
      padding: 0;
    }
    &-list__publish-date {
      padding: 10px 0;
      font-style: italic;
      color: #ccc;
      font-weight: bold;
      font-size: 14px;
    }
}
