{% include "patterns/basics/languages/language-list.html" with alignment="center" %}
<div class="header">
  <div class="header__menu">
      {% include "patterns/basics/images/logo.html" with class="center"%}
  </div>
</div>
{% include "patterns/basics/navigation/navigation-horizontal.html" %}
